<?php

namespace Strig\Category;

use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Strig\Category\Entity\Category;
use Strig\Category\Middleware\CategoryAllMiddleware;
use Strig\Category\Middleware\CategoryByParentMiddleware;
use Strig\Category\Middleware\CategoryImagesMiddleware;
use Strig\Category\Middleware\CategorySpritesMiddleware;
use Strig\Category\Repository\CategoryRepository;
use Zend\Stratigility\MiddlewarePipe;
use function Zend\Stratigility\path;

class CategoryMiddleware implements MiddlewareInterface
{

    protected $pipeline;

    public function __construct(ContainerInterface $container)
    {
        $this->pipeline = new MiddlewarePipe();

        /** @var CategoryManager $manager */
        $manager = $container->get(CategoryManager::class);

        /** @var CategoryRepository $repository */
        $repository = $manager->getRepository(Category::class);

        $this->pipeline->pipe(path('/sprites', new CategorySpritesMiddleware($repository)));
        $this->pipeline->pipe(path('/images', new CategoryImagesMiddleware($repository)));
//        $this->pipeline->pipe(path('/by-parent', new CategoryByParentMiddleware($repository)));
        $this->pipeline->pipe(path('/', new CategoryByParentMiddleware($repository)));
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {

        return $this->pipeline->process($request, $handler);
    }
}
