<?php
declare(strict_types=1);

namespace Strig\Category;

use Ep\Cache\AbstractCacheFactory;
use Zend\ConfigAggregator\ConfigAggregator;
use Zend\ConfigAggregator\PhpFileProvider;

/**
 * The configuration provider for the App module
 *
 * @see https://docs.zendframework.com/zend-component-installer/
 */
class ConfigProvider
{
    /**
     * Returns the configuration array
     *
     * To add a bit of a structure, each section is defined in a separate
     * method which returns an array with its configuration.
     *
     */
    public function __invoke(): array
    {

        return (new ConfigAggregator([
            function () {
                return [
                    'dependencies' => $this->getDependencies(),
                    'repositories' => $this->getRepositories()
                ];
            },
            \Ep\Gath\ConfigProvider::class,
            \Strig\Image\ConfigProvider::class,
            new PhpFileProvider(__DIR__ .'/../config/*.config.php')
        ]))->getMergedConfig();
    }

    /**
     * @return array
     */
    public function getRepositories(): array
    {
        return [
            'aliases' => [
                Entity\Category::class => Repository\CategoryRepository::class,
            ],
            'factories' => [
                Repository\CategoryRepository::class => Repository\CategoryRepositoryFactory::class,
            ]
        ];
    }


    /**
     * Returns the container dependencies
     */
    public function getDependencies(): array
    {
        return [
            'aliases' => [
                Adapter\CategoryAdapterInterface::class => Adapter\WordpressCategoryAdapter::class,
            ],

            'invokables' => [
                Handler\HomePageHandler::class,
            ],
            'factories' => [
                CategoryMiddleware::class => CategoryMiddlewareFactory::class,
                CategoryManager::class => CategoryManagerFactory::class,

                Adapter\GathCategoryAdapter::class => Adapter\GathCategoryAdapterFactory::class,
                Adapter\WordpressCategoryAdapter::class => Adapter\WordpressCategoryAdapterFactory::class,

                Handler\CategoryHandler::class => Handler\CategoryHandlerFactory::class,
                Repository\RepositoryPluginManager::class => Repository\RepositoryPluginManagerFactory::class,

                'redis_cache' => AbstractCacheFactory::class
            ],
        ];
    }
}
